@@ -14,6 +14,15 @@ get_fun_from_pkg <- function(pkg, fun) {
     eval(parse(text = fun))
 }
 
+is.rserver <- function(){
+    RStudio.Version = tryCatch(get("RStudio.Version"), error = function(e) NULL)
+    if(is.null(RStudio.Version)) return(FALSE)
+    if(!is.function(RStudio.Version)) return(FALSE)
+    RStudio.Version()$mode == 'server'
+}
+
+`%||%` <- function(a, b) ifelse(is.null(a), b, a)
+
 ##' open working directory
 ##'
 ##'
@@ -24,7 +33,27 @@ get_fun_from_pkg <- function(pkg, fun) {
 ##' @export
 o <- function(file=".") {
     os <- Sys.info()[1]
-    if (os == "Darwin") {
+    if (is.rserver()) {
+        if (dir.exists(file)) {
+            stop("open directory in RStudio Server is not supported.")
+        }
+        rserver_ip <- getOption("rserver_ip")
+        if (!is.null(rserver_ip)) {
+            rserver_port <- getOption("rserver_port") %||% '8787' 
+            if (!startsWith(rserver_ip, "http")) {
+                rserver_ip = paste0("http://", rserver_ip)
+            }
+            utils::browseURL(
+                       paste0(
+                           paste(rserver_ip, rserver_port, sep=":"),
+                           "/file_show?path=",
+                           file
+                       ))
+        } else {
+            file.edit <- get("file.edit")
+            file.edit(file)   
+        }
+    } else if (os == "Darwin") {
         cmd <- paste("open", file)
         system(cmd)
     } else if (os == "Linux") {
